==> haskell-rope-utf16-splay-0.3.2.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rope-utf16-splay.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rope-utf16-splay
version:              0.3.2.0
visibility:           public
id:                   rope-utf16-splay-0.3.2.0-EAhlSLSfDnoIkRaLL4TSw7
key:                  rope-utf16-splay-0.3.2.0-EAhlSLSfDnoIkRaLL4TSw7
license:              BSD-3-Clause
copyright:            (c) 2018 Olle Fredriksson
maintainer:           fredriksson.olle@gmail.com
author:               Olle Fredriksson
homepage:             https://github.com/ollef/rope-utf16-splay
synopsis:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.

description:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.  This implementation uses splay trees
    instead of the usual finger trees. According to my
    benchmarks, splay trees are faster in most situations.

category:             Data, Text, Language
abi:                  81d1c1b151beef35835db5da73a3c353
exposed:              True
exposed-modules:
    Data.Rope.UTF16 Data.Rope.UTF16.Internal
    Data.Rope.UTF16.Internal.Position Data.Rope.UTF16.Internal.Text
    Data.SplayTree

import-dirs:          /usr/lib/ghc-9.0.2/site-local/rope-utf16-splay-0.3.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rope-utf16-splay-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/rope-utf16-splay-0.3.2.0
hs-libraries:         HSrope-utf16-splay-0.3.2.0-EAhlSLSfDnoIkRaLL4TSw7
depends:              base-4.15.1.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-rope-utf16-splay/html/rope-utf16-splay.haddock

haddock-html:         /usr/share/doc/haskell-rope-utf16-splay/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rope-utf16-splay-0.3.2.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rope-utf16-splay.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rope-utf16-splay
version:              0.3.2.0
visibility:           public
id:                   rope-utf16-splay-0.3.2.0-9Wk94UPuPXGFc8GxmcKIIy
key:                  rope-utf16-splay-0.3.2.0-9Wk94UPuPXGFc8GxmcKIIy
license:              BSD-3-Clause
copyright:            (c) 2018 Olle Fredriksson
maintainer:           fredriksson.olle@gmail.com
author:               Olle Fredriksson
homepage:             https://github.com/ollef/rope-utf16-splay
synopsis:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.

description:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.  This implementation uses splay trees
    instead of the usual finger trees. According to my
    benchmarks, splay trees are faster in most situations.

category:             Data, Text, Language
abi:                  6026d49636ae75b28345af39ff7cea1a
exposed:              True
exposed-modules:
    Data.Rope.UTF16 Data.Rope.UTF16.Internal
    Data.Rope.UTF16.Internal.Position Data.Rope.UTF16.Internal.Text
    Data.SplayTree

import-dirs:          /usr/lib/ghc-9.0.2/site-local/rope-utf16-splay-0.3.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rope-utf16-splay-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rope-utf16-splay
hs-libraries:         HSrope-utf16-splay-0.3.2.0-9Wk94UPuPXGFc8GxmcKIIy
depends:              base-4.15.1.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-rope-utf16-splay/html/rope-utf16-splay.haddock

haddock-html:         /usr/share/doc/haskell-rope-utf16-splay/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
